@@ -112,7 +112,8 @@ do_su (void)
     }
   *rp = 0;
 
-  if (strncmp (result, "Password:", 9))
+  if ((strncmp (result, "Password:", 9))
+	  && (!strstr(result, "Gdk-WARNING")))
     {
       gpe_error_box (result);
       kill (pid, 15);
@@ -161,6 +162,7 @@ main (int argc, char *argv[])
     exit (system (command));
 
   window = gtk_dialog_new ();
+  gtk_window_set_title(GTK_WINDOW(window),_("Permission Control"));
   
   hbox = gtk_hbox_new (FALSE, 0);
   entry = gtk_entry_new ();
